==> tw-server-common-2.1.7-20230616.021343-1-sources.jar: com/elitesland/tw/tw5/server/prd/work/controller/PrdWorkAssignmentHistoryController.java <==
package com.elitesland.tw.tw5.server.prd.work.controller;

import com.elitesland.tw.tw5.api.prd.work.payload.PrdWorkAssignmentHistoryPayload;
import com.elitesland.tw.tw5.api.prd.work.service.PrdWorkAssignmentHistoryService;
import com.elitesland.tw.tw5.api.prd.work.vo.PrdWorkAssignmentHistoryVO;
import com.elitesland.tw.tw5.server.common.TwOutputUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@Api("系统功能处理-指派")
@RestController
@RequiredArgsConstructor
@RequestMapping("/api/work")
@Slf4j
public class PrdWorkAssignmentHistoryController {
    private final PrdWorkAssignmentHistoryService service;
    /**
     * 新建
     *
     * @param payload po类
     * @return result
     */
    @ApiOperation("新增")
    @PostMapping("/assignmentHistory/insert")
    public TwOutputUtil insert(PrdWorkAssignmentHistoryPayload payload) {
        PrdWorkAssignmentHistoryVO vo = service.insert(payload);
        return TwOutputUtil.ok(vo);
    }

    /**
     * 全部修改
     *
     * @param payload po类
     * @return result
     */
    @ApiOperation("修改")
    @PutMapping("/assignmentHistory/update")
    public TwOutputUtil update(PrdWorkAssignmentHistoryPayload payload) {
        PrdWorkAssignmentHistoryVO vo = service.update(payload);
        return TwOutputUtil.ok(vo);
    }
}

==> tw-server-common-3.0.1-20230927.093446-1-sources.jar: com/elitesland/tw/tw5/server/prd/work/controller/PrdWorkAssignmentHistoryController.java <==
package com.elitesland.tw.tw5.server.prd.work.controller;

import com.elitesland.tw.tw5.api.prd.work.payload.PrdWorkAssignmentHistoryPayload;
import com.elitesland.tw.tw5.api.prd.work.service.PrdWorkAssignmentHistoryService;
import com.elitesland.tw.tw5.api.prd.work.vo.PrdWorkAssignmentHistoryVO;
import com.elitesland.tw.tw5.api.common.TwOutputUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@Api("系统功能处理-指派")
@RestController
@RequiredArgsConstructor
@RequestMapping("/api/work")
@Slf4j
public class PrdWorkAssignmentHistoryController {
    private final PrdWorkAssignmentHistoryService service;
    /**
     * 新建
     *
     * @param payload po类
     * @return result
     */
    @ApiOperation("新增")
    @PostMapping("/assignmentHistory/insert")
    public TwOutputUtil insert(PrdWorkAssignmentHistoryPayload payload) {
        PrdWorkAssignmentHistoryVO vo = service.insert(payload);
        return TwOutputUtil.ok(vo);
    }

    /**
     * 全部修改
     *
     * @param payload po类
     * @return result
     */
    @ApiOperation("修改")
    @PutMapping("/assignmentHistory/update")
    public TwOutputUtil update(PrdWorkAssignmentHistoryPayload payload) {
        PrdWorkAssignmentHistoryVO vo = service.update(payload);
        return TwOutputUtil.ok(vo);
    }
}
